/*
 * Copyright (c) 2017, 2020 Oracle and/or its affiliates. All rights reserved.
 */

package javasoft.sqe.tests.positiveinteger.enumeration.enumeration_1;

import jakarta.xml.bind.*;
import jakarta.xml.bind.TypeConstraintException;
import java.math.BigInteger;
import javasoft.sqe.javatest.Status;
import java.io.PrintWriter;
import javasoft.sqe.tests.api.jakarta.xml.bind.CTTest;

public class enumeration1_ValidateCTTests extends CTTest {

    /**
     * Command line starter.
     */
    public static void main(String[] args) {
        enumeration1_ValidateCTTests test = new enumeration1_ValidateCTTests();
        PrintWriter err = new PrintWriter(System.err, true);
        PrintWriter out = new PrintWriter(System.out, true);
        Status status = test.run(args, err, out);
        err.flush();
        out.flush();
        status.exit();
    }

    final BigInteger[] validValues = {new BigInteger("550215893734272"), new BigInteger("846254534438580785"), new BigInteger("43876110718277"),
                                      new BigInteger("7792480394466"), new BigInteger("9936"), new BigInteger("5547"),
                                      new BigInteger("4305434507488021"), new BigInteger("652408347111"), new BigInteger("68527470033184856301"),
                                      new BigInteger("421066425355950"), new BigInteger("6991035"), new BigInteger("9793440067111577"),
                                      new BigInteger("865014204294391")};
    final BigInteger[] invalidValues = {new BigInteger("0"), new BigInteger("1"), new BigInteger("-1"), 
                                        new BigInteger("-9936"), new BigInteger("6991036")};
    
    JAXBElement<BigInteger> elemObj;

    Status testInvalid() {
        for (int i = 0; i < invalidValues.length; ++i){
            
                elemObj.setValue(invalidValues[i]);
                Status status = validate(elemObj);
                if (status.isPassed()) {
                    return Status.failed("" + invalidValues[i] + " is unexpectedly valid");
                }
            
        }
        return Status.passed("OK");
    }

    Status testValid() {
        for (int i = 0; i < validValues.length; ++i){
            elemObj.setValue(validValues[i]);
            Status status = validate(elemObj);
            if (!status.isPassed()){
                return Status.failed("" + validValues[i] + " is unexpectedly invalid");
            }
        }
        return Status.passed("OKAY");
    }

    public Status Validate001( ) {
        String xmlDocName = "enumeration-1-1.xml";
        elemObj = (JAXBElement<BigInteger>)unmarshal(xmlDocName);
        return testValid();
    }

    public Status Validate002( ) {
        String xmlDocName = "enumeration-1-1.xml";
        elemObj = (JAXBElement<BigInteger>)unmarshal(xmlDocName);
        return testInvalid();
    }

    public Status Validate003( ) {
        elemObj = (JAXBElement<BigInteger>)(new ObjectFactory()).createNISTSchemaPositiveIntegerEnumeration1(new BigInteger("7792480394466"));
        
        return testValid();
    }

    public Status Validate004( ) {
        elemObj = (JAXBElement<BigInteger>)(new ObjectFactory()).createNISTSchemaPositiveIntegerEnumeration1(new BigInteger("7792480394466"));
        
        return testInvalid();
    }


}

